<?php

/**
 * @file
 * "Yet Another Multicolumn Layout" for Drupal
 *
 * (en) Form theming functions
 *
 * @copyright       Copyright 2006-2015, Alexander Hass
 * @license         http://www.yaml-fuer-drupal.de/en/terms-of-use
 * @link            http://www.yaml-for-drupal.com
 * @package         yaml-for-drupal
 * @version         7.x-4.1.2.19
 * @lastmodified    2015/02/25
 */

/**
 * Implements hook_form_alter().
 */
function yaml_form_alter(&$form, &$form_state, $form_id) {
  switch ($form_id) {
    case 'search_block_form':
      // Add placeholder text to search field.
      $form['search_block_form']['#attributes']['placeholder'] = t('Search...');
      break;

    case 'search_form':
      // Remove 'container-inline' class from container.
      //$classes = array_flip(array_values($form['basic']['#attributes']['class']));
      //unset($classes['container-inline']);
      //$form['basic']['#attributes']['class'] = array_keys($classes);
      $form['basic']['#attributes']['class'][] = 'ym-fbox';
      break;
  }
}

/**
 * Implements theme_preprocess_addressfield_container().
 */
function yaml_preprocess_addressfield_container(&$variables) {
  $variables['element']['#attributes']['class'][] = 'ym-fbox';
  $variables['element']['#children'] = str_replace(' ym-fbox ', ' ', $variables['element']['#children']);
}

/**
 * Implements theme_preprocess_button().
 */
function yaml_preprocess_button(&$variables) {
  // Add YAML button class to all buttons (including submit).
  $variables['element']['#attributes']['class'][] = 'ym-button';

  // Add 'ym-danger' class to buttons.
  $danger_buttons = array(
    t('Delete'),
    t('Cancel account'),
  );
  if (isset($variables['element']['#value']) && in_array(t($variables['element']['#value']), $danger_buttons)) {
    $variables['element']['#attributes']['class'][] = 'ym-danger';
  }
}

/**
 * Implements theme_preprocess_checkboxes().
 */
function yaml_preprocess_checkboxes(&$variables) {
  // Add yaml universal wrapper to multiple form elements.
  $variables['element']['#attributes']['class'][] = 'ym-fbox-wrap';
  // Remove 'ym-fbox' from all children elements to prevent collisions.
  $variables['element']['#children'] = str_replace(' ym-fbox ', ' ', $variables['element']['#children']);
}

/**
 * Implements theme_preprocess_container().
 */
function yaml_preprocess_container(&$variables) {
  // '#type' seems not defined for custom content types. Core Bug?
  if (isset($variables['element']['#type'])) {
    switch ($variables['element']['#type']) {
      case 'actions':
        // Add YAML button container class to action wrapper.
        $variables['element']['#attributes']['class'][] = 'ym-fbox-footer';
        $variables['element']['#attributes']['class'][] = 'ym-fbox-button';
        break;
    }
  }
}

/**
 * Implements theme_preprocess_form().
 */
function yaml_preprocess_form(&$variables) {
  // Customize form style.
  switch ($variables['element']['#form_id']) {
    case 'diff_node_revisions':
    case 'fivestar_custom_widget':
    case 'lang_dropdown_form':
    case 'workbench_moderation_moderate_form':
      // Add no form classes.
      break;

    case 'search_block_form':
      // NOTE: If search block form is not assigned to region main_navigation,
      // this class may need to be removed to make it a standard ym-form form.
      $variables['element']['#attributes']['class'][] = 'ym-searchform';
      break;

    case 'search_form':
      // Forms that do not support form style switching properly.
      $variables['element']['#attributes']['class'][] = 'ym-form';
      $variables['element']['#attributes']['class'][] = 'linearize-form';
      break;

    case 'user_login_block':
      // Very small forms.
      $variables['element']['#attributes']['class'][] = 'ym-form';
      $variables['element']['#attributes']['class'][] = 'ym-full';
      break;

    default:
      // Linear style (default)
      $variables['element']['#attributes']['class'][] = 'ym-form';
      $variables['element']['#attributes']['class'][] = 'linearize-form';

      // Switch form style based on theme setting.
      $yaml_form_style = theme_get_setting('yaml_form_style');
      if ($yaml_form_style == 'full') {
        // Add full width style.
        $variables['element']['#attributes']['class'][] = 'ym-full';
      }
      elseif ($yaml_form_style == 'columnar') {
        // Allow forms exclusion from columnar style.
        switch ($variables['element']['#form_id']) {
          case 'webform_email_edit_form':
          case 'webform_results_download_form':
            // Don't style this forms as columnar.
            break;

          default:
            // Add columnar style.
            $variables['element']['#attributes']['class'][] = 'ym-columnar';
        }
      }
  }
}

/**
 * Implements theme_preprocess_image_button().
 */
function yaml_preprocess_image_button(&$variables) {
  // @todo: Untested, no repro case! Please report with repro case if broken.
  $variables['element']['#attributes']['class'][] = 'ym-button';
}

/**
 * Implements theme_preprocess_radios().
 */
function yaml_preprocess_radios(&$variables) {
  // Add yaml universal wrapper to multiple form elements.
  $variables['element']['#attributes']['class'][] = 'ym-fbox-wrap';
  // Remove 'ym-fbox' from all children elements to prevent collisions.
  $variables['element']['#children'] = str_replace(' ym-fbox ', ' ', $variables['element']['#children']);
}

/**
 * Implements theme_preprocess_searchfield().
 *
 * Requires http://drupal.org/project/elements.
 */
function yaml_preprocess_searchfield(&$variables) {
  switch ($variables['element']['#name']) {
    case 'search_block_form':
      // Add searchfield class to search 'keyword' <input> element.
      // NOTE: If search block form is not assigned to region main_navigation,
      // this class may need to be removed to make it a standard input field.
      $variables['element']['#attributes']['class'][] = 'ym-searchfield';
      break;
  }
}

/**
 * Implements theme_preprocess_table().
 */
function yaml_preprocess_table(&$variables) {
  if (isset($variables['attributes']['id'])) {
    switch ($variables['attributes']['id']) {
      case 'webform-conditionals-table':
      case 'webform-components':
      case 'webform-emails':
        // Stretch table to full width.
        $variables['attributes']['class'][] = 'full';
        break;
    }
  }

  // Add class 'bordertable' to all tables.
  //$variables['attributes']['class'][] = 'bordertable';
}

/**
 * Implements theme_preprocess_textfield().
 */
function yaml_preprocess_textfield(&$variables) {
  switch ($variables['element']['#name']) {
    case 'search_block_form':
      // Add searchfield class to search 'keyword' <input> element.
      // NOTE: If search block form is not assigned to region main_navigation,
      // this class may need to be removed to make it a standard input field.
      $variables['element']['#attributes']['class'][] = 'ym-searchfield';
      break;
  }

  // Fields with prefix or suffix require .ym-inline class e.g. Captcha fields
  if (!empty($variables['element']['#field_prefix']) || !empty($variables['element']['#field_suffix'])) {
    $variables['element']['#attributes']['class'][] = 'ym-inline';
  }
}

/**
 * Implements theme_preprocess_webform_advanced_redirection_form().
 */
function yaml_preprocess_webform_advanced_redirection_form(&$variables) {
  $variables['form']['redirect_url']['#attributes']['class'][] = 'ym-inline';
}

/**
 * Implements theme_preprocess_webform_advanced_submit_limit_form().
 */
function yaml_preprocess_webform_advanced_submit_limit_form(&$variables) {
  $variables['form']['submit_limit']['#attributes']['class'][] = 'ym-inline';
  $variables['form']['submit_interval']['#attributes']['class'][] = 'ym-inline';
}

/**
 * Implements theme_preprocess_advanced_total_submit_limit_form().
 */
function yaml_preprocess_webform_advanced_total_submit_limit_form(&$variables) {
  $variables['form']['total_submit_limit']['#attributes']['class'][] = 'ym-inline';
  $variables['form']['total_submit_interval']['#attributes']['class'][] = 'ym-inline';
}

/**
 * Implements theme_preprocess_webform_calendar().
 */
function yaml_preprocess_webform_calendar(&$variables) {
  $variables['calendar_classes'][] = 'ym-inline';
}

/**
 * Implements theme_preprocess_webform_date().
 */
function yaml_preprocess_webform_date(&$variables) {
  // #2030869: Theme cannot add classes via theme_preprocess_webform_date().
  $variables['element']['year']['#attributes']['class'][] = 'ym-inline';
  $variables['element']['month']['#attributes']['class'][] = 'ym-inline';
  $variables['element']['day']['#attributes']['class'][] = 'ym-inline';
}

/**
 * Implements theme_preprocess_webform_element().
 */
function yaml_preprocess_webform_element(&$variables) {
  // #2029113: Webform module causes a notice here, if a file field is added/edited.
  if (isset($variables['element']['#type'])) {
    switch ($variables['element']['#type']) {
      case 'date':
      case 'webform_time':
        // Remove 'ym-fbox' from all children elements to prevent collisions.
        $variables['element']['#children'] = str_replace(' ym-fbox ', ' ', $variables['element']['#children']);
        break;
    }
  }
}

/**
 * Implements theme_preprocess_webform_email_add_form().
 */
function yaml_preprocess_webform_email_add_form(&$variables) {
  $variables['form']['email_custom']['#attributes']['class'][] = 'ym-inline';
  $variables['form']['email_component']['#attributes']['class'][] = 'ym-inline';
}

/**
 * Implements theme_preprocess_webform_email_edit_form().
 */
function yaml_preprocess_webform_email_edit_form(&$variables) {
  // Loop through fields, rendering them into radio button options.
  foreach (array('email', 'subject', 'from_address', 'from_name') as $field) {
    foreach (array('custom', 'component') as $option) {
      $variables['form'][$field . '_' . $option]['#attributes']['class'][] = 'ym-inline';
    }
  }
}

/**
 * Implements theme_preprocess_webform_results_download_range().
 */
function yaml_preprocess_webform_results_download_range(&$variables) {
  $variables['element']['latest']['#attributes']['class'][] = 'ym-inline';
  $variables['element']['start']['#attributes']['class'][] = 'ym-inline';
  $variables['element']['end']['#attributes']['class'][] = 'ym-inline';
}

/**
 * Implements theme_preprocess_webform_time().
 */
function yaml_preprocess_webform_time(&$variables) {
  // #2030885: Theme cannot add classes via theme_preprocess_webform_time().
  $variables['element']['hour']['#attributes']['class'][] = 'ym-inline';
  $variables['element']['minute']['#attributes']['class'][] = 'ym-inline';
  $variables['element']['ampm']['#attributes']['class'][] = 'ym-inline';

  $variables['element']['minute']['#prefix'] = '<div class="webform-time-separator ym-fbox-text">:</div>';
}

/**
 * Implements theme_confirm_form().
 */
function yaml_confirm_form($variables) {
  // Surround description with 'ym-fbox' container to add margins.
  $variables['form']['description']['#markup'] = '<div class="ym-fbox">' . $variables['form']['description']['#markup'] . '</div>';
  return drupal_render_children($variables['form']);
}

/**
 * Implements theme_field_multiple_value_form().
 */
function yaml_field_multiple_value_form($variables) {
  $element = $variables['element'];
  $output = '';

  if ($element['#cardinality'] > 1 || $element['#cardinality'] == FIELD_CARDINALITY_UNLIMITED) {
    $table_id = drupal_html_id($element['#field_name'] . '_values');
    $order_class = $element['#field_name'] . '-delta-order';
    $required = !empty($element['#required']) ? theme('form_required_marker', $variables) : '';

    $header = array(
      array(
        'data' => '<label>' . t('!title !required', array('!title' => $element['#title'], '!required' => $required)) . "</label>",
        'colspan' => 2,
        'class' => array('field-label'),
      ),
      t('Order'),
    );
    $rows = array();

    // Sort items according to '_weight' (needed when the form comes back after
    // preview or failed validation)
    $items = array();
    foreach (element_children($element) as $key) {
      if ($key === 'add_more') {
        $add_more_button = &$element[$key];
      }
      else {
        $items[] = &$element[$key];
      }
    }
    usort($items, '_field_sort_items_value_helper');

    // Add the items as table rows.
    foreach ($items as $key => $item) {
      $item['_weight']['#attributes']['class'] = array($order_class);
      $delta_element = drupal_render($item['_weight']);
      $cells = array(
        array('data' => '', 'class' => array('field-multiple-drag')),
        drupal_render($item),
        array('data' => $delta_element, 'class' => array('delta-order')),
      );
      $rows[] = array(
        'data' => $cells,
        'class' => array('draggable'),
      );
    }

    // YAML: Add .ym-fbox
    $output = '<div class="form-item ym-fbox">';
    $output .= theme('table', array('header' => $header, 'rows' => $rows, 'attributes' => array('id' => $table_id, 'class' => array('field-multiple-table'))));
    $output .= $element['#description'] ? '<div class="description">' . $element['#description'] . '</div>' : '';
    $output .= '<div class="clearfix">' . drupal_render($add_more_button) . '</div>';
    $output .= '</div>';

    drupal_add_tabledrag($table_id, 'order', 'sibling', $order_class);
  }
  else {
    foreach (element_children($element) as $key) {
      $output .= drupal_render($element[$key]);
    }
  }

  return $output;
}

/**
 * Implements theme_form_element().
 */
function yaml_form_element($variables) {
  $element = &$variables['element'];

  // This function is invoked as theme wrapper, but the rendered form element
  // may not necessarily have been processed by form_builder().
  $element += array(
    '#title_display' => 'before',
  );

  // Add element #id for #type 'item'.
  if (isset($element['#markup']) && !empty($element['#id'])) {
    $attributes['id'] = $element['#id'];
  }
  // Add element's #type and #name as class to aid with JS/CSS selectors.
  $attributes['class'] = array('form-item');

  // YAML start
  $attributes['class'][] = 'ym-fbox';

  // #2029113: Webform module causes a notice here, if a file field is added/edited.
  if (isset($element['#type'])) {
    // Add custom form classes to form elements.
    switch ($element['#type']) {
      case 'date':
      case 'emailfield': // D8: email
      case 'item';
      case 'file':
      case 'managed_file':
      case 'numberfield': // D8: number
      case 'rangefield': // D8: range
      case 'searchfield': // D8: search
      case 'telfield': // D8: tel
      case 'textarea':
      case 'textfield':
      case 'password':
      case 'urlfield': // D8: url
        $attributes['class'][] = 'ym-fbox-text';
        break;

      case 'select':
        $attributes['class'][] = 'ym-fbox-select';
        break;

      // NOTE: 'ym-fbox-check' class need to be added to 'checkbox' and 'radio'
      // only and not to container 'checkboxes' and 'radios'.
      case 'checkbox':
      case 'radio':
        $attributes['class'][] = 'ym-fbox-check';
        break;
    }
  }
  // YAML end

  if (!empty($element['#type'])) {
    $attributes['class'][] = 'form-type-' . strtr($element['#type'], '_', '-');
  }
  if (!empty($element['#name'])) {
    $attributes['class'][] = 'form-item-' . strtr($element['#name'], array(' ' => '-', '_' => '-', '[' => '-', ']' => ''));
  }
  // Add a class for disabled elements to facilitate cross-browser styling.
  if (!empty($element['#attributes']['disabled'])) {
    $attributes['class'][] = 'form-disabled';
  }
  $output = '<div' . drupal_attributes($attributes) . '>' . "\n";

  // If #title is not set, we don't display any label or required marker.
  if (!isset($element['#title'])) {
    $element['#title_display'] = 'none';
  }
  $prefix = isset($element['#field_prefix']) ? '<span class="field-prefix">' . $element['#field_prefix'] . '</span> ' : '';
  $suffix = isset($element['#field_suffix']) ? ' <span class="field-suffix">' . $element['#field_suffix'] . '</span>' : '';

  // For accessability reasons the .ym-messsage must come before the field.
  // Screenreaders are reading from top to bottom.
  // This also fixes columnar textfields not clickable and checkbox descriptions.
  /* if (!empty($element['#description'])) {
    // YAML
    $output .= '<div class="description ym-message">' . $element['#description'] . "</div>\n";
  } */

  switch ($element['#title_display']) {
    case 'before':
    case 'invisible':
      $output .= ' ' . theme('form_element_label', $variables);
      $output .= ' ' . $prefix . $element['#children'] . $suffix . "\n";
      break;

    case 'after':
      $output .= ' ' . $prefix . $element['#children'] . $suffix;
      $output .= ' ' . theme('form_element_label', $variables) . "\n";
      break;

    case 'none':
    case 'attribute':
      // Output no label and no required marker, only the children.
      $output .= ' ' . $prefix . $element['#children'] . $suffix . "\n";
      break;
  }

  if (!empty($element['#description'])) {
    // YAML
    $output .= '<div class="description ym-message">' . $element['#description'] . "</div>\n";
  }

  $output .= "</div>\n";

  return $output;
}

/**
 * Implements theme_form_element_label().
 */
function yaml_form_element_label($variables) {
  $element = $variables['element'];
  // This is also used in the installer, pre-database setup.
  $t = get_t();

  // If title and required marker are both empty, output no label.
  if ((!isset($element['#title']) || $element['#title'] === '') && empty($element['#required'])) {
    return '';
  }

  // If the element is required, a required marker is appended to the label.
  $required = !empty($element['#required']) ? theme('form_required_marker', array('element' => $element)) : '';

  $title = filter_xss_admin($element['#title']);

  /* YAML start */
  $attributes = array();
  $attributes['class'] = array();

  // Style the label as class option to display inline with the element.
  if ($element['#title_display'] == 'after') {
    $attributes['class'][] = 'option';
  }
  // Show label only to screen readers to avoid disruption in visual flows.
  elseif ($element['#title_display'] == 'invisible') {
    $attributes['class'][] = 'element-invisible';
  }

  // #2029113: Webform module causes a notice here, if a file field is added/edited.
  if (isset($element['#type'])) {
    switch ($element['#type']) {
      case 'radios':
      case 'checkboxes':
      case 'link_field': // link.module
        // Add custom label class to element labels.
        $attributes['class'][] = 'ym-label';
        break;
    }
  }
  if (empty($attributes['class'])) { unset($attributes['class']); }
  /* YAML end */

  if (!empty($element['#id'])) {
    $attributes['for'] = $element['#id'];
  }

  // The leading whitespace helps visually separate fields from inline labels.
  return ' <label' . drupal_attributes($attributes) . '>' . $t('!title !required', array('!title' => $title, '!required' => $required)) . "</label>\n";
}

/**
 * Implements theme_form_required_marker().
 *
 * Override the standard core required marker code.
 */
function yaml_form_required_marker($variables) {
  // This is also used in the installer, pre-database setup.
  $t = get_t();
  $attributes = array(
    'class' => array('form-required', 'ym-required'),
    'title' => $t('This field is required.'),
  );
  return '<span' . drupal_attributes($attributes) . '>*</span>';
}

/**
 * Implements theme_link_field().
 */
function yaml_link_field($vars) {
  //drupal_add_css(drupal_get_path('module', 'link') . '/link.css');
  $element = $vars['element'];
  // Prefix single value link fields with the name of the field.
  if (empty($element['#field']['multiple'])) {
    if (isset($element['url']) && !isset($element['title'])) {
      $element['url']['#title_display'] = 'invisible';
    }
  }

  $output = '';
  if (isset($element['title'])) {
    // Add yaml grid style form.
    $output .= '<div class="ym-fbox-wrap ym-grid">';
    $output .= '  <div class="ym-g50 ym-gl">';
    $output .= '    <div class="ym-gbox-left">' . drupal_render($element['title']) . '</div>';
    $output .= '  </div>';
    $output .= '  <div class="ym-g50 ym-gr">';
    $output .= '    <div class="ym-gbox-right">' . drupal_render($element['url']) . '</div>';
    $output .= '  </div>';
    $output .= '</div>';
  }
  else {
    $output .= drupal_render($element['url']);
  }
  if (!empty($element['attributes']['target'])) {
    $output .= drupal_render($element['attributes']['target']);
  }
  if (!empty($element['attributes']['title'])) {
    $output .= drupal_render($element['attributes']['title']);
  }
  return $output;
}

/**
 * Implements theme_menu_local_tasks().
 *
 * NOTE: There is no preprocess function that allow us to inject classes.
 */
function yaml_menu_local_tasks(&$variables) {
  $output = '';

  if (!empty($variables['primary'])) {
    $variables['primary']['#prefix'] = '<h2 class="element-invisible">' . t('Primary tabs') . '</h2>';
    $variables['primary']['#prefix'] .= '<ul class="tabs primary">';
    $variables['primary']['#suffix'] = '</ul>';
    $output .= drupal_render($variables['primary']);
  }
  if (!empty($variables['secondary'])) {
    $variables['secondary']['#prefix'] = '<h2 class="element-invisible">' . t('Secondary tabs') . '</h2>';
    /* YAML: Add 'clearfix' to make sure it does not overlay with messages */
    $variables['secondary']['#prefix'] .= '<ul class="tabs secondary ym-clearfix">';
    $variables['secondary']['#suffix'] = '</ul>';
    $output .= drupal_render($variables['secondary']);
  }

  return $output;
}

/**
 * Implementation of theme_webform_element().
 */
function yaml_webform_element($variables) {
  // Ensure defaults.
  $variables['element'] += array(
    '#title_display' => 'before',
  );

  $element = $variables['element'];

  // All elements using this for display only are given the "display" type.
  if (isset($element['#format']) && $element['#format'] == 'html') {
    $type = 'display';
  }
  else {
    $type = (isset($element['#type']) && !in_array($element['#type'], array('markup', 'textfield', 'webform_email', 'webform_number'))) ? $element['#type'] : $element['#webform_component']['type'];
  }

  // Convert the parents array into a string, excluding the "submitted" wrapper.
  $nested_level = $element['#parents'][0] == 'submitted' ? 1 : 0;
  $parents = str_replace('_', '-', implode('--', array_slice($element['#parents'], $nested_level)));

  $wrapper_attributes = isset($element['#wrapper_attributes']) ? $element['#wrapper_attributes'] : array('class' => array());
  $wrapper_classes = array(
   'form-item',
   'webform-component',
   'webform-component-' . $type,
  );

  // YAML start
  $wrapper_classes[] = 'ym-fbox';

  // #2029113: Webform module causes a notice here, if a file field is added/edited.
  if (isset($element['#type'])) {
    // Add custom form classes to form elements.
    switch ($element['#type']) {
      case 'date':
      case 'emailfield': // D8: email
      case 'item';
      case 'file':
      case 'managed_file':
      case 'numberfield': // D8: number
      case 'rangefield': // D8: range
      case 'searchfield': // D8: search
      case 'telfield': // D8: tel
      case 'textarea':
      case 'textfield':
      case 'password':
      case 'urlfield': // D8: url
        $wrapper_classes[] = 'ym-fbox-text';
        break;

      case 'select':
        $wrapper_classes[] = 'ym-fbox-select';
        break;

      // NOTE: 'ym-fbox-check' class need to be added to 'checkbox' and 'radio'
      // only and not to container 'checkboxes' and 'radios'.
      case 'checkbox':
      case 'radio':
        $wrapper_classes[] = 'ym-fbox-check';
        break;
    }
  }
  // YAML end

  if (isset($element['#title_display']) && strcmp($element['#title_display'], 'inline') === 0) {
    $wrapper_classes[] = 'webform-container-inline';
  }
  $wrapper_attributes['class'] = array_merge($wrapper_classes, $wrapper_attributes['class']);
  $wrapper_attributes['id'] = 'webform-component-' . $parents;
  $output = '<div ' . drupal_attributes($wrapper_attributes) . '>' . "\n";

  // If #title_display is none, set it to invisible instead - none only used if
  // we have no title at all to use.
  if ($element['#title_display'] == 'none') {
    $variables['element']['#title_display'] = 'invisible';
    $element['#title_display'] = 'invisible';
    if (empty($element['#attributes']['title']) && !empty($element['#title'])) {
      $element['#attributes']['title'] = $element['#title'];
    }
  }
  // If #title is not set, we don't display any label or required marker.
  if (!isset($element['#title'])) {
    $element['#title_display'] = 'none';
  }
  $prefix = isset($element['#field_prefix']) ? '<span class="field-prefix">' . _webform_filter_xss($element['#field_prefix']) . '</span> ' : '';
  $suffix = isset($element['#field_suffix']) ? ' <span class="field-suffix">' . _webform_filter_xss($element['#field_suffix']) . '</span>' : '';

  // For accessability reasons the .ym-messsage must come before the field.
  // Screenreaders are reading from top to bottom.
  // This also fixes columnar textfields not clickable and checkbox descriptions.
  /* if (!empty($element['#description'])) {
    // YAML
    $output .= ' <div class="description ym-message">' . $element['#description'] . "</div>\n";
  } */

  switch ($element['#title_display']) {
    case 'inline':
    case 'before':
    case 'invisible':
      $output .= ' ' . theme('form_element_label', $variables);
      $output .= ' ' . $prefix . $element['#children'] . $suffix . "\n";
      break;

    case 'after':
      $output .= ' ' . $prefix . $element['#children'] . $suffix;
      $output .= ' ' . theme('form_element_label', $variables) . "\n";
      break;

    case 'none':
    case 'attribute':
      // Output no label and no required marker, only the children.
      $output .= ' ' . $prefix . $element['#children'] . $suffix . "\n";
      break;
  }

  if (!empty($element['#description'])) {
    // YAML
    $output .= ' <div class="description ym-message">' . $element['#description'] . "</div>\n";
  }

  $output .= "</div>\n";

  return $output;
}
